@@ -194,30 +194,27 @@ class composite_union:
                 geometry=gpd.GeoSeries(unary_union(data.geometry).intersection(
                     unary_union(data.geometry).buffer(0.0005)))).explode().reset_index().drop(['level_0', 'level_1'],
                                                                                               axis = 1)
+            if unary_data.crs == None:
+                unary_data.crs = data.crs
             self.geodesign = unary_data
-            if self.geodesign.crs == None:
-                self.geodesign.crs = data.crs
-            self.centroid = self.unary_data.centroid
             
         elif data.crs == {'init': 'epsg: 3857'} and buffer == None:
             unary_data = gpd.GeoDataFrame(
                 geometry=gpd.GeoSeries(unary_union(data.geometry).intersection(
                     unary_union(data.geometry).buffer(50)))).explode().reset_index().drop(['level_0', 'level_1'],
                                                                                               axis = 1)
+            if unary_data.crs == None:
+                unary_data.crs = data.crs
             self.geodesign = unary_data
-            if self.geodesign.crs == None:
-                self.geodesign.crs = data.crs
-            self.centroid = self.unary_data.centroid
             
         elif buffer is not None and data.crs != None:
             unary_data = gpd.GeoDataFrame(
                 geometry=gpd.GeoSeries(unary_union(data.geometry).intersection(
                     unary_union(data.geometry).buffer(self.buffer)))).explode().reset_index().drop(['level_0', 'level_1'],
                                                                                               axis = 1)
+            if unary_data.crs == None:
+                unary_data.crs = data.crs
             self.geodesign = unary_data
-            if self.geodesign.crs == None:
-                self.geodesign.crs = data.crs
-            self.centroid = self.unary_data.centroid
             
         elif buffer is not None and data.crs == None:
             data.crs = {'init': 'epsg:4326'}
@@ -225,14 +222,11 @@ class composite_union:
                 geometry=gpd.GeoSeries(unary_union(data.geometry).intersection(
                     unary_union(data.geometry).buffer(0.005)))).explode().reset_index().drop(['level_0', 'level_1'],
                                                                                               axis = 1)
+            if unary_data.crs == None:
+                unary_data.crs = data.crs
             self.geodesign = unary_data
-            if self.geodesign.crs == None:
-                self.geodesign.crs = data.crs
-            self.centroid = self.unary_data.centroid
-            
         else:
             self.geodesign = gpd.GeoDataFrame(geometry=gpd.GeoSeries(Polygon(unary_union(data.geometry).exterior.coords[:])))
-            self.centroid = gpd.GeoDataFrame(geometry=gpd.GeoSeries(Polygon(unary_union(data.geometry).exterior.coords[:])).centroid)
 
 class check_topology:
     
